import * as ec2 from 'aws-cdk-lib/aws-ec2';
import * as efs from 'aws-cdk-lib/aws-efs';
import { Construct } from 'constructs';
import { SyncedAccessPoint } from './synced-access-point';
export interface StatefulFargateNginxProps {
    /**
     * The VPC for the fargate service
     *
     * @default - create a new VPC
     */
    readonly vpc?: ec2.IVpc;
    /**
     * The github repository to clone as the doc root of the nginx
     * @default https://github.com/cristurm/nyan-cat.git
     */
    readonly github?: string;
    /**
     * The EFS FilesSystem as the stateful shared storage of the Fargate service
     *
     * @default - create a new EFS FileSystem
     */
    readonly efsFileSystem?: efs.IFileSystem;
}
export declare class StatefulFargateNginx extends Construct {
    private props;
    private vpc;
    constructor(scope: Construct, id: string, props: StatefulFargateNginxProps);
    private _createVpc;
    private _createEfsFileSystem;
    createSyncedAccessPoint(): SyncedAccessPoint;
}
